/****************************************************************************
 *
 * $Id:
 *
 * Copyright (C) 1998-2006 Lasmea. All rights reserved.
 *
 * This software was developed at:
 * Institut Pascal- UMR 6602
 * 63 175 Aubière Cedex
 * http://ip.univ-bpclermont.fr
 *
 * This file may be distributed under the terms of the Q Public License
 * as defined by Trolltech AS of Norway and appearing in the file
 * LICENSE included in the packaging of this file.
 *
 * Licensees holding valid IPDS Professional Edition licenses may
 * use this file in accordance with the IPDS Commercial License
 * Agreement provided with the Software.
 *
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * Contact . if any conditions of this licensing are
 * not clear to you.
 *
 *
 * Author: Jonathan Courbon - Hemanth Korrapati -
 *
 *****************************************************************************/


#include <iostream>
#include <sstream>
#include <vector>
#include <string>

#include "containers.h"
#include "config.h"
#include "sensor_data.h"



void usage()
{
    std::cout << "============================" << std::endl;
    std::cout << "  GPS Data extraction" << std::endl;
    std::cout << "============================" << std::endl;
    std::cout << "Usage: ./GpsDataExtract sequencePath sensorAlias" << std::endl;
}



int main(int argc, char* argv[])
{

    setlocale (LC_ALL,"C");

    if(argc==3)
    {
      std::string sequencePath(argv[1]);
      std::string sensorAlias(argv[2]);
      
      ConfigTable ctable;
      std::stringstream msg;
      msg << CONFIGFOLDERPATH << "/config_table";
      ctable.readTable(msg.str());
      
      std::vector<Unit> data;
      
      std::string timestamps_file_name=ctable.table[sensorAlias].folderName+ctable.table[sensorAlias].suffix;
      std::string sensor_data_folder=sequencePath+"/"+ctable.table[sensorAlias].folderName+"/";
      
      TimestampInterval timeInt(1352474726081521,1352474722081521);
      getReadings(ctable.table[sensorAlias].sensorName, sensor_data_folder, timestamps_file_name, ctable.table[sensorAlias].tfm, data, timeInt);
      
      std::cout << "================" << std::endl;
      std::cout << "The GPS positions, expressed in meters, for the sensor " << sensorAlias << " in the sequence stored in " << sequencePath << " are: "<< std::endl;
      for(unsigned int i=0;i<data.size();i++)
      {
	  gps_data mygpsdata(data[i].reading);
	  std::cout << "  ( " <<  mygpsdata.lat_l2e << " ; " << mygpsdata.lng_l2e << " )" << std::endl;
      }
      std::cout << "================" << std::endl;
    }
    else
    {
      usage();
    }


  return 0;


}





